Start the Dala Observer web interface for remote node monitoring.
Similar to :observer.start() but runs as a web interface and supports
monitoring remote nodes via RPC.
Start the Dala Observer web interface for remote node monitoring.
Similar to :observer.start() but runs as a web interface and supports
monitoring remote nodes via RPC.